pub struct ToolPolicy {
pub rules: HashMap<String, ToolConstraint>,
pub default: ToolDefaultPolicy,
}Expand description
Which tools, with what limits.
Fields
rules: HashMap<String, ToolConstraint>default: ToolDefaultPolicyImplementations
Sourceimpl ToolPolicy
impl ToolPolicy
pub fn open() -> Self
Sourcepub fn allows_without_approval(&self, tool_name: &str) -> bool
pub fn allows_without_approval(&self, tool_name: &str) -> bool
Whether a tool is executable without any further approval step.
Sourcepub fn requires_approval(&self, tool_name: &str) -> bool
pub fn requires_approval(&self, tool_name: &str) -> bool
Whether this tool requires an explicit approval step before execution.
Sourcepub fn constraint(&self, tool_name: &str) -> Option<&ToolConstraint>
pub fn constraint(&self, tool_name: &str) -> Option<&ToolConstraint>
Access the configured rule for a specific tool, if one exists.
Sourcepub fn is_tool_allowed(&self, tool_name: &str) -> bool
pub fn is_tool_allowed(&self, tool_name: &str) -> bool
Backward-compatible helper retained for existing callers.