TrimOptions

Struct TrimOptions 

pub struct TrimOptions<'a> {
    pub strategy: TrimStrategy,
    pub max_tokens: u32,
    pub token_counter: &'a dyn TokenCounter,
    pub start_on: Option<MessageRole>,
    pub end_on: Option<Vec<MessageRole>>,
}
Options for trim_messages.

Fields

strategy: TrimStrategy

Which end to keep messages from.

max_tokens: u32

Hard token cap.

token_counter: &'a dyn TokenCounter

Token counting implementation.

start_on: Option<MessageRole>

If set, the trimmed window must start with this role.

end_on: Option<Vec<MessageRole>>

If set, the trimmed window must end with one of these roles.