pub struct FallbackProvider { /* private fields */ }Expand description
Wraps a primary and secondary LlmProvider. On transient failure from
the primary, automatically tries the secondary.
Implements LlmProvider itself, so it can be used anywhere a provider is expected
(including inside a MiddlewareStack).
Implementations
Sourceimpl FallbackProvider
impl FallbackProvider
Sourcepub fn new(primary: impl LlmProvider, secondary: impl LlmProvider) -> Self
pub fn new(primary: impl LlmProvider, secondary: impl LlmProvider) -> Self
Create a fallback provider with a primary and secondary.